==> optimum_habana-1.8.2-py3-none-any.whl: optimum/habana/transformers/models/__init__.py <==
from .albert import gaudi_albert_forward
from .bart import (
    gaudi_BartAttention_forward,
    gaudi_BartDecoder_forward,
    gaudi_BartDecoderLayer_forward,
    gaudi_BartEncoder_forward,
    gaudi_BartEncoderLayer_forward,
    gaudi_BartForConditionalGeneration_forward,
    gaudi_BartForConditionalGeneration_prepare_inputs_for_generation,
    gaudi_BartLearnedPositionalEmbedding,
    gaudi_BartModel_forward,
)
from .bloom import (
    GaudiBloomForCausalLM,
    GaudiBloomMLP,
    gaudi_bloom_attention_forward,
    gaudi_bloom_block_forward,
    gaudi_bloom_convert_to_bloom_cache,
    gaudi_bloom_convert_to_standard_cache,
    gaudi_bloom_model_forward,
)
from .codegen import (
    GaudiCodeGenAttention,
    GaudiCodeGenForCausalLM,
    gaudi_codegen_block_forward,
    gaudi_codegen_model_forward,
)
from .esm import (
    gaudi_esm_for_protein_folding_forward,
    gaudi_esmfolding_trunk_forward,
    gaudi_esmoutput_forward,
    gaudi_esmselfoutput_forward,
    gaudi_rot_matmul,
    gaudi_rot_vec_mul,
)
from .falcon import (
    GaudiFalconForCausalLM,
    GaudiFalconModel,
    gaudi_falcon_attention_forward,
    gaudi_falcon_attention_split_heads,
    gaudi_falcon_decoder_layer_forward,
    gaudi_falcon_rotary_embedding_forward,
)
from .gpt2 import GaudiGPT2Attention, GaudiGPT2LMHeadModel, gaudi_gpt2_block_forward, gaudi_gpt2_forward
from .gpt_bigcode import (
    GaudiGPTBigCodeForCausalLM,
    gaudi_gpt_bigcode_attention_forward,
    gaudi_gpt_bigcode_block_forward,
    gaudi_gpt_bigcode_model_forward,
)
from .gpt_neox import (
    GaudiGPTNeoXForCausalLM,
    gaudi_gpt_neox_attention_forward,
    gaudi_gpt_neox_layer_forward,
    gaudi_gpt_neox_model_forward,
)
from .gptj import (
    GaudiGPTJAttention,
    GaudiGPTJForCausalLM,
    gaudi_gptj_block_forward,
    gaudi_gptj_model_forward,
)
from .llama import (
    GaudiLlamaAttention,
    GaudiLlamaDecoderLayer,
    GaudiLlamaForCausalLM,
    GaudiLlamaModel,
    gaudi_llama_rmsnorm_forward,
)
from .modeling_all_models import gaudi_conv1d_forward, gaudi_get_extended_attention_mask, gaudi_invert_attention_mask
from .mpt import (
    GaudiMptForCausalLM,
    GaudiMptModel,
    gaudi_mpt_attention_forward,
    gaudi_mpt_block_forward,
)
from .opt import (
    GaudiOPTForCausalLM,
    GaudiOPTLearnedPositionalEmbedding,
    gaudi_opt_attention_forward,
    gaudi_opt_decoder_forward,
    gaudi_opt_decoder_layer_forward,
    gaudi_opt_model_forward,
)
from .t5 import gaudi_t5_layernorm_forward
from .vit import gaudi_vit_self_attention_forward
from .wav2vec2 import (
    _gaudi_wav2vec2_compute_mask_indices,
    _gaudi_wav2vec2_mask_hidden_states,
    _gaudi_wav2vec2_sample_negative_indices,
    gaudi_wav2vec2_forward,
)

==> optimum_habana-1.10.2-py3-none-any.whl: optimum/habana/transformers/models/__init__.py <==
from .albert import gaudi_albert_forward
from .bart import (
    gaudi_BartAttention_forward,
    gaudi_BartDecoder_forward,
    gaudi_BartDecoderLayer_forward,
    gaudi_BartEncoder_forward,
    gaudi_BartEncoderLayer_forward,
    gaudi_BartForConditionalGeneration_forward,
    gaudi_BartForConditionalGeneration_prepare_inputs_for_generation,
    gaudi_BartLearnedPositionalEmbedding,
    gaudi_BartModel_forward,
)
from .bloom import (
    GaudiBloomForCausalLM,
    GaudiBloomMLP,
    gaudi_bloom_attention_forward,
    gaudi_bloom_block_forward,
    gaudi_bloom_convert_to_bloom_cache,
    gaudi_bloom_convert_to_standard_cache,
    gaudi_bloom_model_forward,
)
from .codegen import (
    GaudiCodeGenAttention,
    GaudiCodeGenForCausalLM,
    gaudi_codegen_block_forward,
    gaudi_codegen_model_forward,
)
from .esm import (
    gaudi_esm_for_protein_folding_forward,
    gaudi_esmfolding_trunk_forward,
    gaudi_rot_matmul,
    gaudi_rot_vec_mul,
)
from .falcon import (
    GaudiFalconForCausalLM,
    GaudiFalconModel,
    gaudi_falcon_attention_forward,
    gaudi_falcon_attention_split_heads,
    gaudi_falcon_decoder_layer_forward,
)
from .gpt2 import GaudiGPT2Attention, GaudiGPT2LMHeadModel, gaudi_gpt2_block_forward, gaudi_gpt2_forward
from .gpt_bigcode import (
    GaudiGPTBigCodeForCausalLM,
    gaudi_gpt_bigcode_attention_forward,
    gaudi_gpt_bigcode_block_forward,
    gaudi_gpt_bigcode_model_forward,
)
from .gpt_neox import (
    GaudiGPTNeoXForCausalLM,
    gaudi_gpt_neox_attention_forward,
    gaudi_gpt_neox_layer_forward,
    gaudi_gpt_neox_model_forward,
)
from .gptj import (
    GaudiGPTJAttention,
    GaudiGPTJForCausalLM,
    gaudi_gptj_block_forward,
    gaudi_gptj_model_forward,
)
from .llama import (
    GaudiLlamaAttention,
    GaudiLlamaDecoderLayer,
    GaudiLlamaForCausalLM,
    GaudiLlamaMLP,
    GaudiLlamaModel,
    gaudi_llama_rmsnorm_forward,
)
from .mistral import (
    GaudiMistralForCausalLM,
    gaudi_mistral_attn_forward,
    gaudi_mistral_decoder_layer_forward,
    gaudi_mistral_model_forward,
)
from .modeling_all_models import gaudi_conv1d_forward, gaudi_get_extended_attention_mask, gaudi_invert_attention_mask
from .mpt import (
    GaudiMptForCausalLM,
    GaudiMptModel,
    gaudi_mpt_attention_forward,
    gaudi_mpt_block_forward,
)
from .opt import (
    GaudiOPTForCausalLM,
    GaudiOPTLearnedPositionalEmbedding,
    gaudi_opt_attention_forward,
    gaudi_opt_decoder_forward,
    gaudi_opt_decoder_layer_forward,
    gaudi_opt_model_forward,
)
from .t5 import (
    gaudi_t5_layernorm_forward,
    gaudi_T5Attention_forward,
    gaudi_T5Block_forward,
    gaudi_T5ForConditionalGeneration_forward,
    gaudi_T5ForConditionalGeneration_prepare_inputs_for_generation,
    gaudi_T5LayerSelfAttention_forward,
    gaudi_T5Stack_forward,
)
from .vit import gaudi_vit_self_attention_forward
from .wav2vec2 import (
    _gaudi_wav2vec2_compute_mask_indices,
    _gaudi_wav2vec2_mask_hidden_states,
    _gaudi_wav2vec2_sample_negative_indices,
    gaudi_wav2vec2_encoder_forward,
    gaudi_wav2vec2_forward,
)
